<sly-template-renderer
  id="{{{ widget.widget_id }}}"
  :state="state"
  :data="data"
  :post="post"
  :session="session"
>
  <div class="container">{{{ widget._content }}}</div>
</sly-template-renderer>
